You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@arrow.apache.org by "Antoine Pitrou (Jira)" <ji...@apache.org> on 2020/01/21 14:50:00 UTC
[jira] [Resolved] (ARROW-7614) [Python] Slow performance in
test_parquet.py::test_set_data_page_size
[ https://issues.apache.org/jira/browse/ARROW-7614?page=com.atlassian.jira.plugin.system.issuetabpanels:all-tabpanel ]
Antoine Pitrou resolved ARROW-7614.
-----------------------------------
Fix Version/s: (was: 1.0.0)
0.16.0
Resolution: Fixed
Issue resolved by pull request 6240
[https://github.com/apache/arrow/pull/6240]
> [Python] Slow performance in test_parquet.py::test_set_data_page_size
> ---------------------------------------------------------------------
>
> Key: ARROW-7614
> URL: https://issues.apache.org/jira/browse/ARROW-7614
> Project: Apache Arrow
> Issue Type: Bug
> Components: Python
> Reporter: Wes McKinney
> Priority: Major
> Labels: pull-request-available
> Fix For: 0.16.0
>
> Time Spent: 50m
> Remaining Estimate: 0h
>
> Slowest test durations:
> {code}
> 3.73s call pyarrow/tests/test_parquet.py::test_set_data_page_size
> 0.05s call pyarrow/tests/test_parquet.py::test_nested_list_nonnullable_roundtrip_bug
> 0.03s call pyarrow/tests/test_parquet.py::test_compression_level
> 0.03s call pyarrow/tests/test_parquet.py::test_dictionary_array_automatically_read
> 0.02s call pyarrow/tests/test_parquet.py::test_statistics_convert_logical_types
> 0.02s call pyarrow/tests/test_parquet.py::test_large_list_records
> 0.01s call pyarrow/tests/test_parquet.py::test_write_nested_zero_length_array_chunk_failure
> 0.01s call pyarrow/tests/test_parquet.py::test_parquet_write_disable_statistics
> 0.01s call pyarrow/tests/test_parquet.py::test_single_pylist_column_roundtrip[int]
> 0.01s call pyarrow/tests/test_parquet.py::test_special_chars_filename
> {code}
> This suggests to me there is something wrong with the feature (possibly doing unnecessary work)
--
This message was sent by Atlassian Jira
(v8.3.4#803005)